Sock Lint
===============================

version number: 0.0.1
author: Jesse Talavera-Greenberg

Overview
--------

API objects used by Sock Puppet

Installation / Usage
--------------------

To install use pip:

    $ pip install socklint


Or clone the repo:

    $ git clone https://github.com/JesseTG/socklint.git
    $ python setup.py install
    
Contributing
------------

TBD

Example
-------

TBD